summaryrefslogtreecommitdiffstats
path: root/quantum/template/template.c
diff options
context:
space:
mode:
Diffstat (limited to 'quantum/template/template.c')
-rw-r--r--quantum/template/template.c41
1 files changed, 24 insertions, 17 deletions
diff --git a/quantum/template/template.c b/quantum/template/template.c
index 7be7dfc3d..58e73cb09 100644
--- a/quantum/template/template.c
+++ b/quantum/template/template.c
@@ -1,29 +1,36 @@
#include "%KEYBOARD%.h"
__attribute__ ((weak))
-void * matrix_init_user(void) {
- // leave these blank
+void matrix_init_user(void) {
+ // leave this function blank - it can be defined in a keymap file
};
__attribute__ ((weak))
-void * matrix_scan_user(void) {
- // leave these blank
-};
+void matrix_scan_user(void) {
+ // leave this function blank - it can be defined in a keymap file
+}
+
+__attribute__ ((weak))
+void led_set_user(uint8_t usb_led) {
+ // leave this function blank - it can be defined in a keymap file
+}
-void * matrix_init_kb(void) {
+void matrix_init_kb(void) {
// put your keyboard start-up code here
// runs once when the firmware starts up
+
+ matrix_init_user();
+}
- if (matrix_init_user) {
- (*matrix_init_user)();
- }
-};
+void matrix_scan_kb(void) {
+ // put your looping keyboard code here
+ // runs every cycle (a lot)
+
+ matrix_scan_user();
+}
-void * matrix_scan_kb(void) {
- // put your looping keyboard code here
- // runs every cycle (a lot)
+void led_set_kb(uint8_t usb_led) {
+ // put your keyboard LED indicator (ex: Caps Lock LED) toggling code here
- if (matrix_scan_user) {
- (*matrix_scan_user)();
- }
-}; \ No newline at end of file
+ led_set_user(usb_led);
+} \ No newline at end of file